.. Django Kubernetes Manager documentation master file, created by
   sphinx-quickstart on Tue Mar 10 17:28:38 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Kubernetes Manager's documentation!
=====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
